#
# spec file for package sitar
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           sitar
Url:            http://sitar.berlios.de/
Version:        1.0.6
Release:        154.22
Summary:        System InformaTion at Runtime
License:        GPL-2.0+
Group:          System/Monitoring
Source0:        sitar-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE fix-syntax-errors-with-newer-perl.patch boo#899992 wbauer@tmo.at -- fix syntax errors when run with the perl in openSUSE 13.1 and higher
Patch:          fix-syntax-errors-with-newer-perl.patch
Patch1:         reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  groff
BuildArch:      noarch
PreReq:         %fillup_prereq

%description 
Sitar prepares system information using perl and binary tools, and by
reading the /proc file system. Output is in HTML, LaTeX and (docbook)
XML, and can be converted to PS and PDF.

This program must be run as "root".

sitar.pl includes scsiinfo by Eric Youngdale, Michael Weller
<eowmob@exp-math.uni-essen.de> and ide_info by David A. Hinds
<dhinds@hyper.stanford.edu>.

The accompanying tool "cfg2scm" is supplied for checking configuration
changes into SCMs (like SVN, CVS, ...) or creating a tar-file with all
relevant files.

Comment: Sitar is an ancient Indian instrument as well.



Authors:
--------
    Matthias Eckermann  <mge@suse.de> 
    and contributors

%prep
%setup -q
%patch -p1
%patch1 -p1

%build
: ${SOURCE_DATE_EPOCH:=1168904229}
export SOURCE_DATE_EPOCH
make

%install
make DESTDIR=${RPM_BUILD_ROOT} install
#
mkdir -p $RPM_BUILD_ROOT%{_fillupdir}
mv $RPM_BUILD_ROOT/etc/sysconfig/sitar   $RPM_BUILD_ROOT%{_fillupdir}/sysconfig.sitar
mv $RPM_BUILD_ROOT/etc/sysconfig/cfg2scm $RPM_BUILD_ROOT%{_fillupdir}/sysconfig.cfg2scm

%files
%defattr(-,root,root)
%attr(700, root, root) /usr/sbin/sitar.pl
%attr(700, root, root) /usr/sbin/sitar
%attr(700, root, root) /usr/sbin/cfg2scm.pl
%dir /usr/share/sitar
%dir /var/lib/support
%doc sitar.html sitar.ps cfg2scm.html cfg2scm.ps LICENSE
/usr/share/man/man1/sitar.1.gz
/usr/share/man/man1/cfg2scm.1.gz
/usr/share/sitar/proc.txt
%{_fillupdir}/sysconfig.sitar
%{_fillupdir}/sysconfig.cfg2scm

%post
%{fillup_only -n sitar}
%{fillup_only -n cfg2scm}

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sun Mar 20 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Mon Oct  6 2014 wbauer@tmo.at
- Added fix-syntax-errors-with-newer-perl.patch: fix syntax errors
  when run with the perl in openSUSE 13.1 and higher (boo#899992)
* Fri Oct 26 2012 coolo@suse.com
- add explicit buildrequire on groff for man pages
* Fri Nov  9 2007 crrodriguez@suse.de
- add missing PreReq tag fixes build in BETA
* Mon Mar 27 2006 mge@suse.de
- Release 1.0.6-260
- Fixes bug #159692 - replace 'cat'-calls with perl-open-close
- Changes on user-interface:
  - introduce "--all" for "--check-consistency --find-unpacked"
  - add si_debug and add status comments for sitar-output
- General factor 8 speedup:
  - improve speed of si_check_consistency by factor 8
    improve speed of si_find_unpacked by factor 6
    thanks to Manfred Hollstein for more effective rpm-queries
  - improve speed of sitar-output-routine by factor 10
    thanks to Adam Spiers for pointing out the bottleneck
* Mon Mar 13 2006 mge@suse.de
- revision 235: sitar-1.0.4
- consolidate diffs
- minor doc/manpage changes
* Tue Mar  7 2006 mge@suse.de
- fixes Bug #155424: "sitar should collect /etc/X11/xorg.conf
  (resp. /etc/X11/XF86Config on older releases)"
  patch: sitar-1.0.3-x11.diff
- fixes Bug #155308: "adopt sitar for: /subdomain
  - > /sys/kernel/security/apparmor"
  patch: sitar-1.0.3-multiple_subdomain_dirs.diff
- (cfg2scm.pl) enhance adding new files in svn-mode
  patch: sitar-1.0.3-cfg2scm.diff
- (sitar.pl) change priority of lspci and lshal
  patch: sitar-1.0.3-lspci.diff
- sitar-1.0.3 revision 231
* Thu Feb 16 2006 mge@suse.de
- Version 1.0.3
- adopted suse/opensuse packaging names for new releases,
  enhance distribution matching, fixes BUG #148363
- correct defattr in spec-file
- enhance manpages and add documentation to *.sysconfig
- now also tested on Mandrake 2005 and FC4
- enhance apparmor_config_path and apparmor_profiles_path to fit
  for different AppArmor releases
- source code reorganization
* Mon Feb  6 2006 mge@suse.de
- Version 1.0.2
- nice, beautiful Makefile by Manfred Hollstein <mh@novell.com> - Thanks!
- split *.pl.in to several files: one per function or
    function-group into the subdirectory sfrags
- fix permissions in spec-file
- remove support.pl and related man-pages
- opotions in cfg2scm.sysconfig, sitar.sysconfig:
    rename    $SITAR_OPT_GNOME to $SITAR_OPT_GCONF
    introduce $SITAR_OPT_LVMARCHIVE
    introduce $CFG2SCM_OPT_LVMARCHIVE
    Introduce new variables, to avoid redundant information:
    SITAR_OPT_ALLCONFIGFILES
    SITAR_OPT_ALLSUBDOMAIN
    SITAR_OPT_ALLSYSCONFIG
- add yast metadata to cfg2scm.sysconfig, sitar.sysconfig
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mge@suse.de
- sitar-1.0.0:
  * merge cfg2scm into sitar
  * add initial HAL support to sitar
  * add /var/lib/support to file-list
  * patch for chkconfig --list (martin.spill at wincor-nixdorf.com)
  * code cleanups (globals)
* Thu Apr 21 2005 mge@suse.de
- update to 0.9.3:
  * final fix for Novell Bug #76733: configfile verification
  * improved man-page
* Mon Apr 11 2005 mge@suse.de
- fixes Novell Bug #76733:
  SITAR should optionally check system consistency
- release 0.9.2:
  * fixes issue around --output=yast2
  * introduces "--check-consistency" as required by #76733
* Mon Apr 11 2005 mge@suse.de
- update to 0.9.1:
  * added initial support for EVMS
  * converted all files to UTF-8
  * moved all external programs to one block;
  enabled PATH-searching for these tools
* Mon Mar 21 2005 mge@suse.de
- more fixes for Novell #73833:
  * lvm scanning, if /etc/lvm/backup does not exist
  * simple output of /proc/mdstat for kernel 2.4/2.6
* Fri Mar 18 2005 mge@suse.de
- update to 0.9.0, fixes #73833
  * #73833: SITAR is missing some required output fields
  md-devices, sitar version
  * add support for XML output
  * add support for Immunix AppArmor
  * improve man page
* Fri Sep 17 2004 mge@suse.de
- update to 0.8.12, fixes #45545:
  * added "lspci" for kernel without /proc/pci
  * don't add "scripts" from /etc/sysconfig/ anymore
  * named html-tables for better X(ht)ML compatibility
  * added some more general information, like "uptime"
  * fixed DOCDIR in Makefile
* Mon Mar 22 2004 mge@suse.de
- update to 0.8.11:
  * move fstab to mount & lvm overview
  * fixed off by one in directory name
  * cleanups
  * data from /etc/lvm/ (LVM2)
  * add output of 'chkconfig -l'
* Mon Mar  1 2004 mge@suse.de
- update to 0.8.10
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Fri Aug 29 2003 mge@suse.de
- fixes SuSE bug #29632
  _POSIX2_VERSION=200112 (Single UNIX Standard, version 3):
  head -1  -> head -n 1
* Fri Aug  8 2003 mge@suse.de
- update to 0.8.8
* Wed Jun 18 2003 ro@suse.de
- added directory to filelist
* Mon Jun  2 2003 ro@suse.de
- remove unpackaged files from buildroot
* Fri Jan 10 2003 mge@suse.de
- (United Linux / SuSE Linux only): split packages by Packager
  make more visible, which packages are originally distributed
  and which are additions
- minor TeX improvements
* Tue Dec 10 2002 mge@suse.de
- Release 0.8.4
- First support of RedHat Linux (by Andreas Rother)
- Support for yast2 selection files
- Better TeX output
- Make --output --format really work
* Thu Aug 29 2002 mge@suse.de
- make sitar recognize UnitedLinux (fixes #18540)
* Thu Aug 15 2002 mge@suse.de
- update to 0.7.2
* Fri Mar  8 2002 kukuk@suse.de
- Add /usr/share/sitar to filelist
* Fri Sep  7 2001 mge@suse.de
- update to 0.6.8: minor changes
* Tue Aug 21 2001 mge@suse.de
- update to 0.6.7
* Fri Jan 12 2001 mge@suse.de
- update to 0.6.4
* Fri Nov 17 2000 kukuk@suse.de
- Remove Requires tag, it is not necessary
* Mon Sep 18 2000 mge@suse.de
- 0.6.3: 	fixed BUG 3865
- since 0.6.0: 	LaTeX output re-introduced
  new copyright-holder: now SuSE Linux Solutions AG
* Tue Jun 27 2000 mge@suse.de
- 0.5.15: improved Table of contents
* Wed Mar  8 2000 mge@suse.de
- 0.5.13: added /etc/fstab, /etc/passwd, /etc/group, /etc/inittab
    /var/spool/fax/etc/config,/var/spool/fax/etc/config.modem
* Mon Mar  6 2000 mge@suse.de
- 0.5.12: improved HTML
* Fri Mar  3 2000 mge@suse.de
- 0.5.11: added /etc/lilo.conf /etc/hosts /etc/aliases
  postfix now via "postconf -n"
  added table of contents
* Wed Mar  1 2000 mge@suse.de
- 0.5.10: moved sitar.pl to /usr/sbin,
  all the other files to /usr/share/sitar
* Mon Feb 21 2000 mge@suse.de
- 0.5.8: sysinfo is sitar now:
  sitar is an ancient indian instrument as well.
* Wed Feb 16 2000 mge@suse.de
- initial public release 0.5.7
